# Perseus Agent Python Library

Perseus Agent Python Library provides core classes to develop agents (workers) responsible for performing asynchronous tasks in the background.

These components have minimal dependencies on other libraries, so that they can be deployed easily.  In addition, these components will keep their interfaces as stable as possible, so that other Python projects can integrate these components without having to worry about changes in the future.


To install the Perseus Agent Python Library, enter the follow command line:

```bash
$ pipenv install perseus-agent-library
```
